@@ -224,7 +224,7 @@ void ChXChartDocument::RefreshData( const chart::ChartDataChangeEvent& /*aEvent*
         if( xDataArray.is() )
         {
             // new data object using own doc shell
-            uno::Reference< lang::XComponent > xComp( SAL_STATIC_CAST( SfxBaseModel*, this ));
+            uno::Reference< lang::XComponent > xComp( (static_cast< SfxBaseModel* >(this)));
             ChXChartDataArray* pNewDataArray = new ChXChartDataArray( xComp, m_pModel );
             chart::XChartDataArray* pSrcArray = xDataArray.get();
 
@@ -234,7 +234,7 @@ void ChXChartDocument::RefreshData( const chart::ChartDataChangeEvent& /*aEvent*
             pNewDataArray->setColumnDescriptions( pSrcArray->getColumnDescriptions() );
 
             // remember the new data as member
-            m_xChartData = SAL_STATIC_CAST( ChXChartData*, pNewDataArray );
+            m_xChartData = (static_cast< ChXChartData* >(pNewDataArray));
         }
     }
 }
@@ -661,9 +661,8 @@ void SAL_CALL ChXChartDocument::setPropertyValue( const ::rtl::OUString& aProper
                             else
                             {
 #if OSL_DEBUG_LEVEL > 1
-                                String aTmpString( aPropertyName );
-                                ByteString aProp( aTmpString, RTL_TEXTENCODING_ASCII_US );
-                                OSL_TRACE( "Diagram: Property %s has an invalid ID (%d)", aProp.GetBuffer(), nWID );
+                                rtl::OString aProp(rtl::OUStringToOString(aPropertyName, RTL_TEXTENCODING_ASCII_US));
+                                OSL_TRACE( "Diagram: Property %s has an invalid ID (%d)", aProp.getStr(), nWID );
 #endif
                             }
                         }
@@ -840,9 +839,8 @@ uno::Any SAL_CALL ChXChartDocument::getPropertyValue( const ::rtl::OUString& aPr
                             else
                             {
 #if OSL_DEBUG_LEVEL > 1
-                                String aTmpString( aPropertyName );
-                                ByteString aProp( aTmpString, RTL_TEXTENCODING_ASCII_US );
-                                OSL_TRACE( "Diagram: Property %s has an invalid ID (%d)", aProp.GetBuffer(), nWID );
+                                rtl::OString aProp(rtl::OUStringToOString(aPropertyName, RTL_TEXTENCODING_ASCII_US));
+                                OSL_TRACE( "Diagram: Property %s has an invalid ID (%d)", aProp.getStr(), nWID );
 #endif
                             }
                         }
@@ -1111,10 +1109,10 @@ uno::Reference< chart::XChartData > SAL_CALL ChXChartDocument::getData() throw(
     osl::Guard< osl::Mutex > aGuard( GetMutex());
     if( ! m_xChartData.is())
     {
-        uno::Reference< lang::XComponent > xComp( SAL_STATIC_CAST( SfxBaseModel*, this ));
+        uno::Reference< lang::XComponent > xComp( (static_cast< SfxBaseModel* >(this)));
         // XChartData is inherited twice
-        m_xChartData = SAL_STATIC_CAST( chart::XChartDataArray*,
-                                        new ChXChartDataArray( xComp, m_pModel ));
+        m_xChartData = (static_cast< chart::XChartDataArray* >(
+                                        new ChXChartDataArray( xComp, m_pModel )));
     }
 
     return m_xChartData;
