@@ -198,17 +198,6 @@ SO2_IMPL_CLASS2_DLL(SvEmbeddedObject,SvFactory,SvPersist,SvPseudoObject,
     return NULL;
 }
 
-void SvEmbeddedObject::TestMemberObjRef( BOOL /*bFree*/ )
-{
-}
-
-#ifdef TEST_INVARIANT
-void SvEmbeddedObject::TestMemberInvariant( BOOL bPrint )
-{
-    (void)bPrint;
-}
-#endif
-
 /************************************************************************
 |*    SvEmbeddedObject::SvEmbeddedObject()
 |*
