@@ -112,8 +112,8 @@ namespace binfilter {
 
 /*N*/ SfxPoolItem* SwFmtVertOrient::Create( SvStream& rStrm, USHORT nIVer ) const
 /*N*/ {
-/*N*/   long nPos;
-/*N*/   BYTE nOrient, nRelation;
+/*N*/   sal_Int32 nPos(0);
+/*N*/   BYTE nOrient(0), nRelation(0);
 /*N*/   rStrm >> nPos >> nOrient >> nRelation;
 /*N*/
 /*N*/   // fix #48690#: In 4.0-Doks wurde bei VERT_NONE die Relation nicht
@@ -137,8 +137,8 @@ namespace binfilter {
 
 /*N*/ SfxPoolItem* SwFmtHoriOrient::Create( SvStream& rStrm, USHORT nIVer ) const
 /*N*/ {
-/*N*/   long nPos;
-/*N*/   BYTE nOrient, nRelation, bToggle = 0;
+/*N*/   sal_Int32 nPos(0);
+/*N*/   BYTE nOrient(0), nRelation(0), bToggle(0);
 /*N*/   rStrm >> nPos >> nOrient >> nRelation;
 /*N*/
 /*N*/   if( nIVer >= IVER_HORIORIENT_TOGGLE )
@@ -256,7 +256,7 @@ namespace binfilter {
 /*N*/   if( pIo )
 /*N*/       pNew->SetMap( pIo->InImageMap( sURL1, sTargetFrameName1, bServerMap ) );
 /*N*/   if( nIVer>=1 )
-/*N*/       rStrm.ReadByteString( sName1, rStrm.GetStreamCharSet() );
+/*N*/       sName1 = rStrm.ReadUniOrByteString( rStrm.GetStreamCharSet() );
 /*N*/
 /*N*/   // fix #30592#: Boese Falle: Beim setzen einer URL wird eine Image-Map
 /*N*/   // wieder geloescht.
@@ -325,8 +325,8 @@ SfxPoolItem* SwFmtFtnEndAtTxtEnd::Create( SvStream &rStrm, USHORT nVer ) const
         String sPostfix, sSuffix1;
         rStrm >> nOffset1
               >> nFmtType;
-        rStrm.ReadByteString( sPostfix, rStrm.GetStreamCharSet() );
-        rStrm.ReadByteString( sSuffix1, rStrm.GetStreamCharSet() );
+        sPostfix = rStrm.ReadUniOrByteString( rStrm.GetStreamCharSet() );
+        sSuffix1 = rStrm.ReadUniOrByteString( rStrm.GetStreamCharSet() );
 
         pNew->SetNumType( (SvxExtNumType)nFmtType );
         pNew->SetOffset( nOffset1 );
@@ -530,7 +530,7 @@ SfxPoolItem* SwGammaGrf::Create(SvStream & rStrm, USHORT ) const
 /*N*/   sal_Char cChr = ' ';
 /*N*/   if( nV )
 /*N*/       rStrm >> cChr;
-/*N*/   sal_Unicode c = ByteString_ConvertToUnicode( cChr, rStrm.GetStreamCharSet() );
+/*N*/   sal_Unicode c = ByteString::ConvertToUnicode( cChr, rStrm.GetStreamCharSet() );
 /*N*/   return new SwFmtHardBlank( c, FALSE );
 /*N*/ }
 
@@ -640,10 +640,9 @@ SfxPoolItem* SwGammaGrf::Create(SvStream & rStrm, USHORT ) const
 /*N*/ SfxPoolItem* SwNumRuleItem::Create( SvStream& rStrm,
 /*N*/                                            USHORT nIVer ) const
 /*N*/ {
-/*N*/   String sTmp;
 /*N*/   UINT16 nPoolId;
 /*N*/
-/*N*/   rStrm.ReadByteString( sTmp, rStrm.GetStreamCharSet() );
+/*N*/   String sTmp = rStrm.ReadUniOrByteString( rStrm.GetStreamCharSet() );
 /*N*/   if( nIVer>0 )
 /*N*/   {
 /*N*/       // Pool-NumRules muessen evtl. noch umbenannt werden.
@@ -710,9 +709,8 @@ SfxPoolItem* SwGammaGrf::Create(SvStream & rStrm, USHORT ) const
 /*N*/   if( 0 == nIVer )
 /*N*/   {
 /*N*/       sal_Char* dummy;
-/*N*/       ByteString sValue;
-/*N*/       rStrm.ReadByteString( sValue );
-/*N*/       dVal = strtod( sValue.GetBuffer(), &dummy );
+/*N*/       rtl::OString sValue = read_lenPrefixed_uInt8s_ToOString<sal_uInt16>(rStrm);
+/*N*/       dVal = strtod( sValue.getStr(), &dummy );
 /*N*/   }
 /*N*/   else
 /*N*/       rStrm >> dVal;
