@@ -73,6 +73,7 @@
 #include <com/sun/star/beans/XPropertyContainer.hpp>
 #include <com/sun/star/beans/PropertyStateChangeEvent.hpp>
 #include <com/sun/star/beans/PropertyChangeEvent.hpp>
+#include <rtl/strbuf.hxx>
 //undef to prevent error (from bf_sfx2/docfile.cxx)
 #undef SEQUENCE
 #include <com/sun/star/text/SetVariableType.hpp>
@@ -464,10 +465,9 @@ BOOL SwXFieldMaster::supportsService(const OUString& rServiceName) throw( Runtim
         }
         if( pEntry )
         {
-            ByteString aTmp( RTL_CONSTASCII_STRINGPARAM(
-                            "com.sun.star.text.fieldmaster."));
-            aTmp.Append( pEntry );
-            bRet = rServiceName.equalsAsciiL(aTmp.GetBuffer(), aTmp.Len());
+            rtl::OString aTmp(rtl::OStringBuffer(RTL_CONSTASCII_STRINGPARAM(
+                            "com.sun.star.text.fieldmaster.")).append(pEntry).makeStringAndClear());
+            bRet = rServiceName.equalsAsciiL(aTmp.getStr(), aTmp.getLength());
         }
     }
     return bRet;
@@ -587,10 +587,10 @@ void SwXFieldMaster::setPropertyValue( const OUString& rPropertyName,
         String sTypeName(uTmp);
         SwFieldType* pLclType = m_pDoc->GetFldType(nResTypeId, sTypeName);
 
-        String sTable(SW_RES(STR_POOLCOLL_LABEL_TABLE));
-        String sDrawing(SW_RES(STR_POOLCOLL_LABEL_DRAWING));
-        String sFrame(SW_RES(STR_POOLCOLL_LABEL_FRAME));
-        String sIllustration(SW_RES(STR_POOLCOLL_LABEL_ABB));
+        String sTable(SW_RESSTR(STR_POOLCOLL_LABEL_TABLE));
+        String sDrawing(SW_RESSTR(STR_POOLCOLL_LABEL_DRAWING));
+        String sFrame(SW_RESSTR(STR_POOLCOLL_LABEL_FRAME));
+        String sIllustration(SW_RESSTR(STR_POOLCOLL_LABEL_ABB));
 
         if(pLclType ||
             (RES_SETEXPFLD == nResTypeId &&
@@ -2540,9 +2540,6 @@ uno::Any SwXFieldEnumeration::nextElement(void)
     if (!(nNextIndex < aItems.getLength()))
         throw NoSuchElementException();
 
-#if OSL_DEBUG_LEVEL > 1
-    uno::Reference< XTextField > *pItems = aItems.getArray();
-#endif
     uno::Reference< XTextField >  &rxFld = aItems.getArray()[ nNextIndex++ ];
     uno::Any aRet(&rxFld, ::getCppuType((const uno::Reference<XTextField>*)0));
     rxFld = 0;  // free memory for item that is not longer used
